/*
 * Copyright (c) 2008-present Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/*global Ext, NX*/

/**
 * Licensing details panel.
 *
 * @since 3.0
 */
Ext.define('NX.proui.view.licensing.LicensingDetails', {
  extend: 'NX.view.SettingsPanel',
  alias: 'widget.nx-proui-licensing-details',
  requires: [
    'NX.I18n'
  ],

  /**
   * @override
   */
  initComponent: function() {
    Ext.apply(this, {
      settingsForm: [
        {
          xtype: 'nx-settingsform',
          api: {
            load: 'NX.direct.licensing_Licensing.read'
          },
          itemId: 'details',
          defaults: {
            xtype: 'textfield',
            readOnly: true
          },
          items: [
            { name: 'contactCompany', fieldLabel: NX.I18n.get('Licensing_LicensingDetails_Company_FieldLabel') },
            { name: 'contactName', fieldLabel: NX.I18n.get('Licensing_LicensingDetails_Name_FieldLabel') },
            { name: 'contactEmail', fieldLabel: NX.I18n.get('Licensing_LicensingDetails_Email_FieldLabel') },
            { name: 'effectiveDate', fieldLabel: NX.I18n.get('Licensing_LicensingDetails_EffectiveDate_FieldLabel'), xtype:'nx-datedisplayfield' },
            { name: 'expirationDate', fieldLabel: NX.I18n.get('Licensing_LicensingDetails_ExpirationDate_FieldLabel'), xtype:'nx-datedisplayfield' },
            { name: 'licenseType', fieldLabel: NX.I18n.get('Licensing_LicensingDetails_Type_FieldLabel') },
            { name: 'licensedConnections', fieldLabel: NX.I18n.get('Licensing_LicensingDetails_Connections_FieldLabel') }
          ],
          buttons: undefined
        },
        {
          xtype: 'form',
          title: NX.I18n.get('Licensing_LicensingDetails_InstallLicense_Title'),
          ui: 'nx-subsection',
          frame: true,

          api: {
            submit: 'NX.direct.licensing_Licensing.install'
          },

          items: [
            {
              xtype: 'label',
              html: NX.I18n.get('Licensing_LicensingDetails_InstallLicense_Html')
            },
            {
              xtype: 'fileuploadfield',
              name: 'license',
              allowBlank: false,
              buttonText: NX.I18n.get('Licensing_LicensingDetails_LicenseSelect_Button'),
              buttonConfig: {
                glyph: 'xf016@FontAwesome' /* fa-file-o */
              }
            }
          ],

          buttonAlign: 'left',
          buttons: [
            { text: NX.I18n.get('Licensing_LicensingDetails_LicenseInstall_Button'), action: 'install', formBind: true, ui: 'nx-primary', glyph: 'xf023@FontAwesome' /* fa-lock */ }
          ]
        },
        {
          xtype: 'form',
          title: NX.I18n.get('Licensing_LicensingDetails_LicenseUninstall_Title'),
          ui: 'nx-subsection',
          frame: true,

          items: [
            {
              xtype: 'label',
              html: NX.I18n.get('Licensing_LicensingDetails_LicenseUninstall_Html')
            }
          ],

          buttonAlign: 'left',
          buttons: [
            { text: NX.I18n.get('Licensing_LicensingDetails_LicenseUninstall_Button'), action: 'uninstall', ui: 'nx-primary', glyph: 'xf023@FontAwesome' /* fa-lock */ }
          ]
        }
      ]
    });

    this.callParent();
  }

});
